@@ -27,13 +27,9 @@ import tempfile
 import subprocess
 import pyalpm
 import Namcap.package
-from Namcap.util import is_elf, script_type
+from Namcap.util import script_type
 from Namcap.ruleclass import *
 
-if not pyalpm.checkinit():
-	pyalpm.initialize()
-	pyalpm.options.dbpath = "/var/lib/pacman"
-
 def scanshebangs(fileobj, filename, scripts):
 	"""
 	Scan a file for shebang and stores the interpreter name.
@@ -80,8 +76,9 @@ def findowners(scriptlist):
 
 		# strip leading slash
 		scriptpath = out.strip()[1:].decode('utf-8', 'surrogateescape')
-		for pkg in pyalpm.get_localdb().pkgcache:
-			if scriptpath in pkg.files:
+		for pkg in Namcap.package.get_installed_packages():
+			pkg_files = [fname for fname, fsize, fmode in pkg.files]
+			if scriptpath in pkg_files:
 				pkglist.setdefault(pkg.name, set()).add(s)
 				scriptfound.add(s)
 
